@@ -6,6 +6,7 @@
 
 #include "manager.h"
 #include "assetrepository_p.h"
+#include "backends/srbijavozbackend.h"
 #include "backends/zpcgbackend.h"
 #include "journeyreply.h"
 #include "journeyrequest.h"
@@ -37,12 +38,12 @@
 #include "backends/hafasmgatebackend.h"
 #include "backends/hafasquerybackend.h"
 #include "backends/ivvassbackend.h"
+#include "backends/motisbackend.h"
 #include "backends/navitiabackend.h"
 #include "backends/oebbbackend.h"
 #include "backends/openjourneyplannerbackend.h"
 #include "backends/opentripplannergraphqlbackend.h"
 #include "backends/opentripplannerrestbackend.h"
-#include "backends/pasazieruvilciensbackend.h"
 #include "backends/ltglinkbackend.h"
 #include "gbfs/gbfsbackend.h"
 
@@ -58,6 +59,7 @@
 
 #include <functional>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace KPublicTransport;
 
 static inline void initResources() {
@@ -131,34 +133,49 @@ void ManagerPrivate::loadNetworks()
         return;
     }
 
-    QDirIterator it(QStringLiteral(":/org.kde.kpublictransport/networks"), QDir::Files);
-    while (it.hasNext()) {
-        QFile f(it.next());
-        if (!f.open(QFile::ReadOnly)) {
-            qCWarning(Log) << "Failed to open public transport network configuration:" << f.errorString();
-            continue;
-        }
+    QStringList searchDirs;
+#ifndef Q_OS_ANDROID
+    searchDirs = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+#endif
+    searchDirs.push_back(u":/"_s);
 
-        QJsonParseError error;
-        const auto doc = QJsonDocument::fromJson(f.readAll(), &error);
-        if (error.error != QJsonParseError::NoError) {
-            qCWarning(Log) << "Failed to parse public transport network configuration:" << error.errorString() << it.fileName();
-            continue;
-        }
-
-        auto net = loadNetwork(doc.object());
-        if (net) {
-            net->setBackendId(it.fileInfo().baseName());
-            net->init();
-            if (!net->attribution().isEmpty()) {
-                m_attributions.push_back(net->attribution());
+    for (const auto &searchDir : searchDirs) {
+        QDirIterator it(searchDir + "/org.kde.kpublictransport/networks"_L1, {u"*.json"_s}, QDir::Files);
+        while (it.hasNext()) {
+            it.next();
+            const auto id = it.fileInfo().baseName();
+            if (std::any_of(m_backends.begin(), m_backends.end(), [&id](const auto &backend) { return backend.identifier() == id; })) {
+                // already seen in another location
+                continue;
             }
 
-            auto b = BackendPrivate::fromJson(doc.object());
-            BackendPrivate::setImpl(b, std::move(net));
-            m_backends.push_back(std::move(b));
-        } else {
-            qCWarning(Log) << "Failed to load public transport network configuration config:" << it.fileName();
+            QFile f(it.filePath());
+            if (!f.open(QFile::ReadOnly)) {
+                qCWarning(Log) << "Failed to open public transport network configuration:" << f.errorString();
+                continue;
+            }
+
+            QJsonParseError error;
+            const auto doc = QJsonDocument::fromJson(f.readAll(), &error);
+            if (error.error != QJsonParseError::NoError) {
+                qCWarning(Log) << "Failed to parse public transport network configuration:" << error.errorString() << it.fileName();
+                continue;
+            }
+
+            auto net = loadNetwork(doc.object());
+            if (net) {
+                net->setBackendId(id);
+                net->init();
+                if (!net->attribution().isEmpty()) {
+                    m_attributions.push_back(net->attribution());
+                }
+
+                auto b = BackendPrivate::fromJson(doc.object());
+                BackendPrivate::setImpl(b, std::move(net));
+                m_backends.push_back(std::move(b));
+            } else {
+                qCWarning(Log) << "Failed to load public transport network configuration config:" << it.fileName();
+            }
         }
     }
 
@@ -185,11 +202,12 @@ std::unique_ptr<AbstractBackend> ManagerPrivate::loadNetwork(const QJsonObject &
         EfaBackend,
         IvvAssBackend,
         OpenJourneyPlannerBackend,
+        MotisBackend,
         GBFSBackend,
         AccessibilityCloudBackend,
-        PasazieruVilciensBackend,
         LTGLinkBackend,
-        ZPCGBackend
+        ZPCGBackend,
+        SrbijavozBackend
     >(type, obj);
 }
 
@@ -407,7 +425,7 @@ bool ManagerPrivate::queryJourney(const AbstractBackend* backend, const JourneyR
 
 bool ManagerPrivate::queryStopover(const AbstractBackend *backend, const StopoverRequest &req, StopoverReply *reply)
 {
-    auto cache = Cache::lookupDeparture(backend->backendId(), req.cacheKey());
+    auto cache = Cache::lookupStopover(backend->backendId(), req.cacheKey());
     switch (cache.type) {
         case CacheHitType::Negative:
             qCDebug(Log) << "Negative cache hit for backend" << backend->backendId();
@@ -669,7 +687,7 @@ StopoverReply* Manager::queryStopover(const StopoverRequest &req) const
             }
 
             // backend doesn't support this, let's try to emulate
-            if (context.type == RequestContext::Next && req.mode() == StopoverRequest::QueryDeparture) {
+            if (context.type == RequestContext::Next) {
                 auto r = req;
                 r.setDateTime(context.dateTime);
                 if (d->queryStopover(context.backend, r, reply)) {
